Deploy a misha.browser app to a local directory
browser_deploy_local.RdCopies the bundled app.R and optionally a config file to a target
directory so it can be served by Shiny Server.
Usage
browser_deploy_local(
dest_dir,
config = NULL,
config_name = "config.yaml",
profile = "server",
server_root = NULL,
overwrite = FALSE,
write_env = TRUE,
extra_files = NULL,
touch_restart = TRUE
)Arguments
- dest_dir
Target directory to deploy into.
- config
Path to a YAML config file to copy. When NULL, no config is copied.
- config_name
Filename to use in the destination (default: "config.yaml").
- profile
Profile name to set in the deployment environment (default: "server").
- server_root
Optional path to misha root on the server. If provided, updates the misha_root in the specified profile of the deployed config file.
- overwrite
Logical, overwrite existing files if TRUE.
- write_env
Logical, write a
.Renvironwith MISHA_BROWSER_* vars.- extra_files
Optional character vector of file paths to copy as-is.
- touch_restart
Logical, create or update
restart.txtin destination.