Plot the genome browser
browser_plot.RdRenders all panels for the current or specified region.
Arguments
- browser
Browser object
- region
Optional region to plot (uses current if NULL)
- gene
Optional gene name to center on
- span
Optional span in bp (used with gene)
- parallel
Logical, enable parallel panel data extraction (default: from option). Requires
futurepackage and a parallel plan to be set (e.g.,future::plan(future::multisession)).- profile
Logical, enable profiling output (default: from option)
Examples
if (FALSE) { # \dontrun{
browser <- browser_create(config = "config.yaml")
browser_plot(browser)
browser_plot(browser, gene = "Tbx5", span = 2e6)
# Enable profiling
options(misha.browser.profile = TRUE)
browser_plot(browser)
# Enable parallel extraction
future::plan(future::multisession, workers = 4)
browser_plot(browser, parallel = TRUE)
} # }